@@ -2,7 +2,7 @@
 --- Functions for command-line scripts.
 local cmd = {}
 
-local loader = require("luarocks.loader")
+local manif = require("luarocks.manif")
 local util = require("luarocks.util")
 local path = require("luarocks.path")
 local cfg = require("luarocks.core.cfg")
@@ -94,7 +94,7 @@ do
       elseif args.project_tree then
          local tree = args.project_tree
          table.insert(cfg.rocks_trees, 1, { name = "project", root = tree } )
-         loader.load_rocks_trees()
+         manif.load_rocks_tree_manifests()
          path.use_tree(tree)
       elseif cfg.local_by_default then
          if cfg.home_tree then
@@ -103,7 +103,7 @@ do
       elseif project_dir then
          local project_tree = project_dir .. "/lua_modules"
          table.insert(cfg.rocks_trees, 1, { name = "project", root = project_tree } )
-         loader.load_rocks_trees()
+         manif.load_rocks_tree_manifests()
          path.use_tree(project_tree)
       else
          local trees = cfg.rocks_trees
@@ -172,6 +172,31 @@ local function die(message, exitcode)
    os.exit(exitcode or cmd.errorcodes.UNSPECIFIED)
 end
 
+local function search_lua_in_path(lua_version, verbose)
+   local path_sep = (package.config:sub(1, 1) == "\\" and ";" or ":")
+   local all_tried = {}
+   for bindir in os.getenv("PATH"):gmatch("[^"..path_sep.."]+") do
+      local parentdir = dir.path((bindir:gsub("[\\/][^\\/]+[\\/]?$", "")))
+      local detected, tried = util.find_lua(parentdir, lua_version)
+      if detected then
+         return detected
+      else
+         table.insert(all_tried, tried)
+      end
+      bindir = dir.path(bindir)
+      detected = util.find_lua(bindir, lua_version)
+      if detected then
+         return detected
+      else
+         table.insert(all_tried, tried)
+      end
+   end
+   return nil, "Could not find " ..
+               (lua_version and "Lua " .. lua_version or "Lua") ..
+               " in PATH." ..
+               (verbose and " Tried:\n" .. table.concat(all_tried, "\n") or "")
+end
+
 local init_config
 do
    local detect_config_via_args
@@ -244,17 +269,9 @@ do
          end
       
          if lua_version then
-            local path_sep = (package.config:sub(1, 1) == "\\" and ";" or ":")
-            for bindir in os.getenv("PATH"):gmatch("[^"..path_sep.."]+") do
-               local parentdir = bindir:gsub("[\\/][^\\/]+[\\/]?$", "")
-               local detected = util.find_lua(dir.path(parentdir), lua_version)
-               if detected then
-                  return detected
-               end
-               detected = util.find_lua(bindir, lua_version)
-               if detected then
-                  return detected
-               end
+            local detected = search_lua_in_path(lua_version)
+            if detected then
+               return detected
             end
             return {
                lua_version = lua_version,
@@ -387,17 +404,22 @@ Enabling completion for Fish:
       "rockspecs of in-development versions.")
    parser:option("--server", "Fetch rocks/rockspecs from this server "..
       "(takes priority over config file).")
+      :hidden_name("--from")
    parser:option("--only-server", "Fetch rocks/rockspecs from this server only "..
       "(overrides any entries in the config file).")
       :argname("<server>")
+      :hidden_name("--only-from")
    parser:option("--only-sources", "Restrict downloads to paths matching the given URL.")
       :argname("<url>")
+      :hidden_name("--only-sources-from")
    parser:option("--namespace", "Specify the rocks server namespace to use.")
+      :convert(string.lower)
    parser:option("--lua-dir", "Which Lua installation to use.")
       :argname("<prefix>")
    parser:option("--lua-version", "Which Lua version to use.")
       :argname("<ver>")
    parser:option("--tree", "Which tree to operate on.")
+      :hidden_name("--to")
    parser:flag("--local", "Use the tree in the user's home directory.\n"..
       "To enable it, see '"..program.." help path'.")
    parser:flag("--global", "Use the system tree when `local_by_default` is `true`.")
@@ -410,11 +432,6 @@ Enabling completion for Fish:
 
    -- Used internally to force the use of a particular project tree
    parser:option("--project-tree"):hidden(true)
-   -- Compatibility for old names of some options
-   parser:option("--to"):target("tree"):hidden(true)
-   parser:option("--from"):target("server"):hidden(true)
-   parser:option("--only-from"):target("only_server"):hidden(true)
-   parser:option("--only-sources-from"):target("only_sources"):hidden(true)
 
    for _, module in util.sortedpairs(cmd_modules) do
       module.add_to_parser(parser)
@@ -534,15 +551,18 @@ function cmd.run_command(description, commands, external_namespace, ...)
 
    -- if the Lua interpreter wasn't explicitly found before cfg.init,
    -- try again now.
+   local tried
    if not lua_found then
       if cfg.variables.LUA_DIR then
-         lua_found = util.find_lua(cfg.variables.LUA_DIR, cfg.lua_version)
+         lua_found, tried = util.find_lua(cfg.variables.LUA_DIR, cfg.lua_version, args.verbose)
+      else
+         lua_found, tried = search_lua_in_path(cfg.lua_version, args.verbose)
       end
    end
 
-   if not lua_found then
-      util.warning("Could not find a Lua " .. cfg.lua_version .. " interpreter in your PATH. " ..
-                   "Modules may not install with the correct configurations. " ..
+   if not lua_found and args.command ~= "config" and args.command ~= "help" then
+      util.warning(tried ..
+                   "\nModules may not install with the correct configurations. " ..
                    "You may want to specify the path prefix to your build " ..
                    "of Lua " .. cfg.lua_version .. " using --lua-dir")
    end
@@ -584,6 +604,10 @@ function cmd.run_command(description, commands, external_namespace, ...)
       cfg.local_cache = dir.path(fs.system_cache_dir(), "luarocks")
    end
 
+   if args.no_manifest then
+      cfg.no_manifest = true
+   end
+
    if not args.command then
       parser:epilog(variables_help..get_config_text(cfg))
       util.printout()
