@@ -19,10 +19,13 @@ In the latter case, the rock version may be given as a second argument.]],
       :summary("Unpack the contents of a rock.")
 
    cmd:argument("rock", "A rock file or the name of a rock.")
+      :action(util.namespaced_name_action)
    cmd:argument("version", "Rock version.")
       :args("?")
 
    cmd:flag("--force", "Unpack files even if the output directory already exists.")
+   cmd:flag("--check-lua-versions", "If the rock can't be found, check repository "..
+      "and report if it is available for another Lua version.")
 end
 
 --- Load a rockspec file to the given directory, fetches the source
@@ -149,13 +152,11 @@ end
 -- @return boolean or (nil, string): true if successful or nil followed
 -- by an error message.
 function unpack.command(args)
-   local ns_name = util.adjust_name_and_namespace(args.rock, args)
-
    local url, err
-   if ns_name:match(".*%.rock") or ns_name:match(".*%.rockspec") then
-      url = ns_name
+   if args.rock:match(".*%.rock") or args.rock:match(".*%.rockspec") then
+      url = args.rock
    else
-      url, err = search.find_src_or_rockspec(ns_name, args.version, true)
+      url, err = search.find_src_or_rockspec(args.rock, args.namespace, args.version, args.check_lua_versions)
       if not url then
          return nil, err
       end
