@@ -215,6 +215,10 @@ function util.this_program(default)
    return prog
 end
 
+function util.format_rock_name(name, namespace, version)
+   return (namespace and namespace.."/" or "")..name..(version and " "..version or "")
+end
+
 function util.deps_mode_option(parser, program)
    local cfg = require("luarocks.core.cfg")
 
@@ -338,30 +342,6 @@ function util.LQ(s)
    return ("%q"):format(s)
 end
 
---- Normalize the --namespace option and the user/rock syntax for namespaces.
--- If a namespace is given in user/rock syntax, update the --namespace option;
--- If a namespace is given in --namespace option, update the user/rock syntax.
--- In case of conflicts, the user/rock syntax takes precedence.
-function util.adjust_name_and_namespace(ns_name, args)
-   assert(type(ns_name) == "string" or not ns_name)
-   assert(type(args) == "table")
-
-   if not ns_name then
-      return
-   elseif ns_name:match("%.rockspec$") or ns_name:match("%.rock$") then
-      return ns_name
-   end
-
-   local name, namespace = util.split_namespace(ns_name)
-   if namespace then
-      args.namespace = namespace
-   end
-   if args.namespace then
-      name = args.namespace .. "/" .. name
-   end
-   return name:lower()
-end
-
 -- Split name and namespace of a package name.
 -- @param ns_name a name that may be in "namespace/name" format
 -- @return string, string? - name and optionally a namespace
@@ -373,6 +353,27 @@ function util.split_namespace(ns_name)
    return ns_name
 end
 
+--- Argparse action callback for namespaced rock arguments.
+function util.namespaced_name_action(args, target, ns_name)
+   assert(type(args) == "table")
+   assert(type(target) == "string")
+   assert(type(ns_name) == "string" or not ns_name)
+
+   if not ns_name then
+      return
+   end
+
+   if ns_name:match("%.rockspec$") or ns_name:match("%.rock$") then
+      args[target] = ns_name
+   else
+      local name, namespace = util.split_namespace(ns_name)
+      args[target] = name:lower()
+      if namespace then
+         args.namespace = namespace:lower()
+      end
+   end
+end
+
 function util.deep_copy(tbl)
    local copy = {}
    for k, v in pairs(tbl) do
@@ -454,7 +455,7 @@ do
 
       local ljv
       if cfg.lua_version == "5.1" then
-         ljv = util.popen_read(Q(cfg.variables["LUA_BINDIR"] .. "/" .. cfg.lua_interpreter) .. ' -e "io.write(tostring(jit and jit.version:gsub([[^%w-JIT ]], [[]])))"')
+         ljv = util.popen_read(Q(cfg.variables["LUA_BINDIR"] .. "/" .. cfg.lua_interpreter) .. ' -e "io.write(tostring(jit and jit.version:gsub([[^%S+ ]], [[]])))"')
          if ljv == "nil" then
             ljv = nil
          end
@@ -480,7 +481,7 @@ do
          end
       end
 
-      find_lua_bindir = function(prefix, luaver)
+      find_lua_bindir = function(prefix, luaver, verbose)
          local names = {}
          if luaver then
             insert_lua_variants(names, luaver)
@@ -494,11 +495,11 @@ do
          end
          table.insert(names, "lua" .. exe_suffix)
 
-         local bindirs = { prefix .. "/bin", prefix }
          local tried = {}
-         for _, d in ipairs(bindirs) do
+         local dir_sep = package.config:sub(1, 1)
+         for _, d in ipairs({ prefix .. dir_sep .. "bin", prefix }) do
             for _, name in ipairs(names) do
-               local lua_exe = d .. "/" .. name
+               local lua_exe = d .. dir_sep .. name
                local is_wrapper, err = util.lua_is_wrapper(lua_exe)
                if is_wrapper == false then
                   local lv = util.check_lua_version(lua_exe, luaver)
@@ -516,13 +517,13 @@ do
                         and ("Lua " .. luaver .. " interpreter")
                         or  "Lua interpreter"
          return nil, interp .. " not found at " .. prefix .. "\n" ..
-                     "Tried:\t" .. table.concat(tried, "\n\t")
+                     (verbose and "Tried:\t" .. table.concat(tried, "\n\t") or "")
       end
    end
 
-   function util.find_lua(prefix, luaver)
+   function util.find_lua(prefix, luaver, verbose)
       local lua_interpreter, bindir
-      lua_interpreter, bindir, luaver = find_lua_bindir(prefix, luaver)
+      lua_interpreter, bindir, luaver = find_lua_bindir(prefix, luaver, verbose)
       if not lua_interpreter then
          return nil, bindir
       end
@@ -628,5 +629,20 @@ function util.get_rocks_provided(rockspec)
    return rocks_provided
 end
 
-return util
+function util.remove_doc_dir(name, version)
+   local path = require("luarocks.path")
+   local fs = require("luarocks.fs")
+   local dir = require("luarocks.dir")
 
+   local install_dir = path.install_dir(name, version)
+   for _, f in ipairs(fs.list_dir(install_dir)) do
+      local doc_dirs = { "doc", "docs" }
+      for _, d in ipairs(doc_dirs) do
+         if f == d then
+            fs.delete(dir.path(install_dir, f))
+         end
+      end
+   end
+end
+
+return util
